@@ -2,6 +2,7 @@ import logging
 import traceback
 
 import ssl
+from io import BytesIO
 from typing import Optional
 
 from pypsql_api.config.types import Session
@@ -30,9 +31,18 @@ cipher_list = "ECDH+ECDSA+AESGCM:" \
               "!aNULL:!MD5:!DSS:"
 
 
-def reset(io: ReadingIO) -> ReadingIO:
-    io.buff.seek(0)
-    return io
+def reset(rio: ReadingIO) -> ReadingIO:
+    rio.buff.seek(0)
+    return rio
+
+
+def prefix_len(rio: ReadingIO) -> ReadingIO:
+    bts = rio.buff.read()
+    wio = WritingIO()
+    wio.write_int32(len(bts))
+    wio.write_bytes(bts)
+
+    return ReadingIO(ReadingIO(wio.buff))
 
 
 def read_ssl_request(context: Context):
@@ -48,7 +58,7 @@ def read_ssl_request(context: Context):
         if ssl_request.request_code == 196608:
             # ancient mode
             logging.error("reading startup message from ancient")
-            return read_startup_message(context, inner_buff=reset(ssl_request.inner_buff))
+            return read_startup_message(context, inner_buff=prefix_len(reset(ssl_request.inner_buff)))
         else:
 
             if context.key_file and context.cert_file:
