@@ -1,4 +1,5 @@
 import io
+import logging
 from dataclasses import dataclass
 from typing import Any, Optional, Tuple, List
 
@@ -33,6 +34,8 @@ class StartupMessage:
 
     @staticmethod
     def read(buff: ReadingIO):
+        logging.error(f"Reading startup message using {buff}")
+
         inner_buff, message_len = buff.read_int32_delim_message()
 
         if not inner_buff:
