@@ -39,7 +39,7 @@ def move_state(context: Any, state: State) -> Tuple[Any, str]:
 
 processes = {
     Names.READ_SSL_REQUEST: State(name=Names.READ_SSL_REQUEST,
-                                  allowed={Names.WRITE_SSL_NO, Names.WRITE_SSL_YES, Names.CLOSE}, fn=read_ssl_request),
+                                  allowed={Names.WRITE_SSL_NO, Names.WRITE_SSL_YES, Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST, Names.CLOSE}, fn=read_ssl_request),
     Names.WRITE_SSL_NO: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE, Names.CLOSE},
                               fn=write_ssl_resp_no),
     Names.WRITE_SSL_YES: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE, Names.CLOSE},
